@@ -1,7 +1,8 @@
+from __future__ import absolute_import
 
-from file_utils import StorageFileUtils
-from meta_utils import MetaDataUtils
-from general_utils import GeneralUtils
+from csr_cloud.file_utils import StorageFileUtils
+from csr_cloud.meta_utils import MetaDataUtils
+from csr_cloud.general_utils import GeneralUtils
 
 class AzureUtils(StorageFileUtils, MetaDataUtils, GeneralUtils):
     def __init__(self, account_name, account_key, cloudname, feature):
